#[non_exhaustive]pub struct CreateDataCatalogInputBuilder { /* private fields */ }Expand description
A builder for CreateDataCatalogInput.
Implementations
Sourceimpl CreateDataCatalogInputBuilder
impl CreateDataCatalogInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the data catalog to create. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
For FEDERATED type the catalog name has following considerations and limits:
-
The catalog name allows special characters such as
_ , @ , \ , -. These characters are replaced with a hyphen (-) when creating the CFN Stack Name and with an underscore (_) when creating the Lambda Function and Glue Connection Name. -
The catalog name has a theoretical limit of 128 characters. However, since we use it to create other resources that allow less characters and we prepend a prefix to it, the actual catalog name limit for
FEDERATEDcatalog is 64 - 23 = 41 characters.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the data catalog to create. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
For FEDERATED type the catalog name has following considerations and limits:
-
The catalog name allows special characters such as
_ , @ , \ , -. These characters are replaced with a hyphen (-) when creating the CFN Stack Name and with an underscore (_) when creating the Lambda Function and Glue Connection Name. -
The catalog name has a theoretical limit of 128 characters. However, since we use it to create other resources that allow less characters and we prepend a prefix to it, the actual catalog name limit for
FEDERATEDcatalog is 64 - 23 = 41 characters.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the data catalog to create. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
For FEDERATED type the catalog name has following considerations and limits:
-
The catalog name allows special characters such as
_ , @ , \ , -. These characters are replaced with a hyphen (-) when creating the CFN Stack Name and with an underscore (_) when creating the Lambda Function and Glue Connection Name. -
The catalog name has a theoretical limit of 128 characters. However, since we use it to create other resources that allow less characters and we prepend a prefix to it, the actual catalog name limit for
FEDERATEDcatalog is 64 - 23 = 41 characters.
Sourcepub fn type(self, input: DataCatalogType) -> Self
pub fn type(self, input: DataCatalogType) -> Self
The type of data catalog to create: LAMBDA for a federated catalog, GLUE for an Glue Data Catalog, and HIVE for an external Apache Hive metastore. FEDERATED is a federated catalog for which Athena creates the connection and the Lambda function for you based on the parameters that you pass.
For FEDERATED type, we do not support IAM identity center.
Sourcepub fn set_type(self, input: Option<DataCatalogType>) -> Self
pub fn set_type(self, input: Option<DataCatalogType>) -> Self
The type of data catalog to create: LAMBDA for a federated catalog, GLUE for an Glue Data Catalog, and HIVE for an external Apache Hive metastore. FEDERATED is a federated catalog for which Athena creates the connection and the Lambda function for you based on the parameters that you pass.
For FEDERATED type, we do not support IAM identity center.
Sourcepub fn get_type(&self) -> &Option<DataCatalogType>
pub fn get_type(&self) -> &Option<DataCatalogType>
The type of data catalog to create: LAMBDA for a federated catalog, GLUE for an Glue Data Catalog, and HIVE for an external Apache Hive metastore. FEDERATED is a federated catalog for which Athena creates the connection and the Lambda function for you based on the parameters that you pass.
For FEDERATED type, we do not support IAM identity center.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the data catalog to be created.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the data catalog to be created.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the data catalog to be created.
Sourcepub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to parameters.
To override the contents of this collection use set_parameters.
Specifies the Lambda function or functions to use for creating the data catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
-
The
GLUEtype takes a catalog ID parameter and is required. Thecatalog_idis the account ID of the Amazon Web Services account to which the Glue Data Catalog belongs.catalog-id=catalog_id-
The
GLUEdata catalog type also applies to the defaultAwsDataCatalogthat already exists in your account, of which you can have only one and cannot modify.
-
-
The
FEDERATEDdata catalog type uses one of the following parameters, but not both. Useconnection-arnfor an existing Glue connection. Useconnection-typeandconnection-propertiesto specify the configuration setting for a new connection.-
connection-arn: -
lambda-role-arn(optional): The execution role to use for the Lambda function. If not provided, one is created. -
connection-type:MYSQL|REDSHIFT|...., connection-properties:"" For
, use escaped JSON text, as in the following example."{\"spill_bucket\":\"my_spill\",\"spill_prefix\":\"athena-spill\",\"host\":\"abc12345.snowflakecomputing.com\",\"port\":\"1234\",\"warehouse\":\"DEV_WH\",\"database\":\"TEST\",\"schema\":\"PUBLIC\",\"SecretArn\":\"arn:aws:secretsmanager:ap-south-1:111122223333:secret:snowflake-XHb67j\"}"
-
Sourcepub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
Specifies the Lambda function or functions to use for creating the data catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
-
The
GLUEtype takes a catalog ID parameter and is required. Thecatalog_idis the account ID of the Amazon Web Services account to which the Glue Data Catalog belongs.catalog-id=catalog_id-
The
GLUEdata catalog type also applies to the defaultAwsDataCatalogthat already exists in your account, of which you can have only one and cannot modify.
-
-
The
FEDERATEDdata catalog type uses one of the following parameters, but not both. Useconnection-arnfor an existing Glue connection. Useconnection-typeandconnection-propertiesto specify the configuration setting for a new connection.-
connection-arn: -
lambda-role-arn(optional): The execution role to use for the Lambda function. If not provided, one is created. -
connection-type:MYSQL|REDSHIFT|...., connection-properties:"" For
, use escaped JSON text, as in the following example."{\"spill_bucket\":\"my_spill\",\"spill_prefix\":\"athena-spill\",\"host\":\"abc12345.snowflakecomputing.com\",\"port\":\"1234\",\"warehouse\":\"DEV_WH\",\"database\":\"TEST\",\"schema\":\"PUBLIC\",\"SecretArn\":\"arn:aws:secretsmanager:ap-south-1:111122223333:secret:snowflake-XHb67j\"}"
-
Sourcepub fn get_parameters(&self) -> &Option<HashMap<String, String>>
pub fn get_parameters(&self) -> &Option<HashMap<String, String>>
Specifies the Lambda function or functions to use for creating the data catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
-
The
GLUEtype takes a catalog ID parameter and is required. Thecatalog_idis the account ID of the Amazon Web Services account to which the Glue Data Catalog belongs.catalog-id=catalog_id-
The
GLUEdata catalog type also applies to the defaultAwsDataCatalogthat already exists in your account, of which you can have only one and cannot modify.
-
-
The
FEDERATEDdata catalog type uses one of the following parameters, but not both. Useconnection-arnfor an existing Glue connection. Useconnection-typeandconnection-propertiesto specify the configuration setting for a new connection.-
connection-arn: -
lambda-role-arn(optional): The execution role to use for the Lambda function. If not provided, one is created. -
connection-type:MYSQL|REDSHIFT|...., connection-properties:"" For
, use escaped JSON text, as in the following example."{\"spill_bucket\":\"my_spill\",\"spill_prefix\":\"athena-spill\",\"host\":\"abc12345.snowflakecomputing.com\",\"port\":\"1234\",\"warehouse\":\"DEV_WH\",\"database\":\"TEST\",\"schema\":\"PUBLIC\",\"SecretArn\":\"arn:aws:secretsmanager:ap-south-1:111122223333:secret:snowflake-XHb67j\"}"
-
Appends an item to tags.
To override the contents of this collection use set_tags.
A list of comma separated tags to add to the data catalog that is created. All the resources that are created by the CreateDataCatalog API operation with FEDERATED type will have the tag federated_athena_datacatalog="true". This includes the CFN Stack, Glue Connection, Athena DataCatalog, and all the resources created as part of the CFN Stack (Lambda Function, IAM policies/roles).
A list of comma separated tags to add to the data catalog that is created. All the resources that are created by the CreateDataCatalog API operation with FEDERATED type will have the tag federated_athena_datacatalog="true". This includes the CFN Stack, Glue Connection, Athena DataCatalog, and all the resources created as part of the CFN Stack (Lambda Function, IAM policies/roles).
A list of comma separated tags to add to the data catalog that is created. All the resources that are created by the CreateDataCatalog API operation with FEDERATED type will have the tag federated_athena_datacatalog="true". This includes the CFN Stack, Glue Connection, Athena DataCatalog, and all the resources created as part of the CFN Stack (Lambda Function, IAM policies/roles).
Sourcepub fn build(self) -> Result<CreateDataCatalogInput, BuildError>
pub fn build(self) -> Result<CreateDataCatalogInput, BuildError>
Consumes the builder and constructs a CreateDataCatalogInput.
Sourceimpl CreateDataCatalogInputBuilder
impl CreateDataCatalogInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateDataCatalogOutput, SdkError<CreateDataCatalogError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateDataCatalogOutput, SdkError<CreateDataCatalogError, HttpResponse>>
Sends a request with this input using the given client.